import click

from nicky.managers import SourceManager
from nicky.utils import PREFIX_WORDS, SUFFIX_WORDS


@click.command(help='Add new suffix or Prefix. You can add multiple values with comma separated.')
@click.argument('kind')
@click.argument('values')
@click.option('--lang', '-l', default='ko', help='language')
def add(kind, values, lang):
    sm = SourceManager(lang)
    value_list = values.split(',')

    if kind in PREFIX_WORDS:
        sm.pre_add(value_list)
    elif kind in SUFFIX_WORDS:
        sm.suf_add(value_list)
    else:
        click.BadArgumentUsage('Invalid arguments: {}'.format(kind))



import os

BASE_DIR = os.path.dirname(__file__)
SOURCE_PATH = os.path.join(BASE_DIR, 'nicknames')
COMMANDS_PATH = os.path.join(BASE_DIR, 'commands')

SUPPORT_LANG_LIST = [
    'ko',
]

PREFIX_WORDS = ('p', 'pre', 'prefix', 'pr')
SUFFIX_WORDS = ('s', 'suf', 'suffix', 'su')



import click

from nicky.base import Nicky


@click.command(help='nickname generating')
@click.argument('count', default=1)
@click.option('--lang', '-l', default='ko', help='language')
def name(count, lang):
    nicky = Nicky(lang)
    nickname = nicky.get_nicknames(count)
    print('\n'.join(nickname))



import click

from nicky.managers import SourceManager
from nicky.utils import PREFIX_WORDS, SUFFIX_WORDS


@click.command(help='Sorting suffix or prefix file')
@click.argument('kind', default='')
@click.option('--lang', '-l', default='ko', help='language')
def sort(kind, lang):
    sm = SourceManager(lang)
    if kind in PREFIX_WORDS:
        sm.pre_sorting()
    elif kind in SUFFIX_WORDS:
        sm.suf_ordering()
    elif not kind:
        sm.suf_ordering()
        sm.pre_sorting()
    else:
        click.BadArgumentUsage('Invalid arguments: {}'.format(kind))




import random

from nicky.managers import LoadManager


class Nicky:
    def __init__(self, lang='ko'):
        self.lang = lang
        self.loader = LoadManager(lang)

    def get_nicknames(self, count=1):
        prefix = self.loader.get_prefix_list()
        suffix = self.loader.get_suffix_list()
        return ['{} {}'.format(random.choice(prefix), random.choice(suffix)) for _ in range(count)]



#! /usr/bin/env python
import importlib
import os

import click

from nicky.utils import COMMANDS_PATH


@click.group()
def cli():
    pass


for i in [f for f in os.listdir(COMMANDS_PATH) if f.find('cd_') == 0]:
    name = i.replace('.py', '')
    module = importlib.import_module('nicky.commands.{}'.format(name))
    cli.add_command(getattr(module, name.replace('cd_', '')))

if __name__ == '__main__':
    cli()



import click

from nicky.managers import SourceManager


@click.command(help='copy nickname source file')
@click.argument('path')
@click.option('--lang', '-l', default='ko', help='language')
def copy(path, lang):
    sm = SourceManager(lang)
    sm.copy(path)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nicky', 'nicky.commands']

package_data = \
{'': ['*'], 'nicky': ['nicknames/en/*', 'nicknames/jp/*', 'nicknames/ko/*']}

install_requires = \
['click==7.0.0']

entry_points = \
{'console_scripts': ['nicky = nicky.cli:cli']}

setup_kwargs = {
    'name': 'nicky',
    'version': '2.0.0b2',
    'description': 'Nicky the nicknamer',
    'long_description': "Nicky\n-------------\n.. image:: https://badge.fury.io/py/nicky.svg\n    :target: https://badge.fury.io/py/nicky\n\n\nNicky is the nicknamer. You can make funny nickname with nicky!\n\nHow to use\n==============\n\n1. with pip\n^^^^^^^^^^^^\n\n.. code::\n\n    # install local env\n    pip install nicky\n\n    # or install globally.\n    pip install --user nicky\n\n    nicky name\n    > 향긋한 까치\n\n    nicky name 5\n    > 신성한 스콘\n    > 똘망똘망한 오미자차\n    > 향긋한 스테이크\n    > 활기찬 사탕\n    > 엄청난 순대\n..\n\n2. with code\n^^^^^^^^^^^^\n\n.. code::\n\n    from nicky import Nicky\n\n    n = Nicky(lang='ko')\n    n.get_nicknames(3)\n    > ['신성한 스콘', '똘망똘망한 오미자차', '향긋한 스테이크']\n..\n\nIf you want more, just type :code:`nicky [command] --help`\n\n\nLocalization and more nicknames\n-----------------------------------\n\nFolk and clone this project. and add your language code folder in :code:`nicky/nicknames`\n\nAfter then, you can use :code:`nicky-cli.py` to add your nickname prefix and suffix.\n\n.. code::\n\n    python3 nicky-cli.py add [prefix|suffix|pre|suf|p|s] {values} [-l|--lang] {language}\n..\n\n    You can add multiple values. Separate your values with comma like :code:`a,b,c`. Remember, there's no space.\n\n**example)**\n\n.. code::\n\n    python3 nicky-cli.py add pre melon,potato,tomato --lang en\n..\n\nAfter all, pull requests to master branch.",
    'author': 'jrog612',
    'author_email': 'jrog612@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/jrog612/nicky',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



import os

from nicky.utils import SOURCE_PATH, SUPPORT_LANG_LIST


class PathManager:
    @classmethod
    def lang_path(cls, lang='ko'):
        if lang not in SUPPORT_LANG_LIST:
            raise ValueError('unsupported language.')
        return os.path.join(SOURCE_PATH, lang)

    @classmethod
    def suffix_path(cls, lang='ko'):
        return os.path.join(cls.lang_path(lang), 'suffix.txt')

    @classmethod
    def prefix_path(cls, lang='ko'):
        return os.path.join(cls.lang_path(lang), 'prefix.txt')


class LoadManager:
    def __init__(self, lang='ko'):
        self.lang = lang

    def get_prefix_file(self, mode='r'):
        return open(PathManager.prefix_path(self.lang), mode)

    def get_suffix_file(self, mode='r'):
        return open(PathManager.suffix_path(self.lang), mode)

    def get_suffix_list(self):
        return [i for i in self.get_suffix_file().read().split('\n') if i]

    def get_prefix_list(self):
        return [i for i in self.get_prefix_file().read().split('\n') if i]


class SourceManager:
    def __init__(self, lang='ko'):
        self.lang = lang
        self.loader = LoadManager(lang)

    def write(self, values, item_list, f):
        for v in values:
            if not v:
                continue
            elif v in item_list:
                print('{} is already exists'.format(v))
            else:
                item_list.append(v)

        item_list.sort()
        f.write('\n'.join(item_list))
        f.close()

    def copy(self, path):
        pass

    def suf_ordering(self,):
        li = self.loader.get_suffix_list()
        f = self.loader.get_suffix_file('w')
        self.write([], li, f)

    def pre_sorting(self):
        li = self.loader.get_prefix_list()
        f = self.loader.get_prefix_file('w')
        self.write([], li, f)

    def suf_add(self, values):
        li = self.loader.get_suffix_list()
        f = self.loader.get_suffix_file('w')
        self.write(values, li, f)

    def pre_add(self, values):
        li = self.loader.get_prefix_list()
        f = self.loader.get_prefix_file('w')
        self.write(values, li, f)
